@@ -67,7 +67,7 @@ class Monthly(Base):
     # Index of first meteorological column
     _first_met_col = 2
 
-    # Data tapes
+    # Data types
     _types: dict = {
         'tavg': 'float64',
         'tmin': 'float64',
@@ -246,7 +246,7 @@ class Monthly(Base):
         if isinstance(loc, pd.DataFrame):
             self._stations = loc.index
         elif isinstance(loc, Point):
-            stations = loc.get_stations('hourly', start, end)
+            stations = loc.get_stations('monthly', start, end)
             self._stations = stations.index
         else:
             if not isinstance(loc, list):
